@@ -18,11 +18,13 @@ import datetime
 import fnmatch
 import glob
 import hashlib
+import importlib
 import itertools
 import logging
 import platform
 import pkg_resources
 import os
+import re
 import shutil
 import subprocess
 import sys
@@ -115,7 +117,8 @@ class Extension(metaclass=abc.ABCMeta):
             try:
                 return parse(self, *args, **kwargs)
             except Exception:
-                self.ext_meta["corrupted"] = True
+                if os.path.exists(self.work_dir):
+                    self.ext_meta["corrupted"] = True
                 raise
             finally:
                 if os.path.exists(self.temp_dir):
@@ -337,15 +340,27 @@ class Extension(metaclass=abc.ABCMeta):
         elif self.name == "Path":
             stored_meta["build_dir"] = self.conf["build_dir"]
 
-        if "clade_version" not in stored_meta:
-            stored_meta["clade_version"] = Extension.get_clade_version()
+        if "versions" not in stored_meta:
+            stored_meta["versions"] = dict()
+
+        if "clade" not in stored_meta["versions"]:
+            stored_meta["versions"]["clade"] = Extension.get_clade_version()
+
+        if "python" not in stored_meta["versions"]:
+            stored_meta["versions"]["python"] = platform.python_version()
+
+        if "pip" not in stored_meta["versions"]:
+            stored_meta["versions"]["pip"] = pkg_resources.get_distribution("pip").version
+
+        if "gcc" not in stored_meta["versions"]:
+            stored_meta["versions"]["gcc"] = self.get_program_version("gcc")
+
+        if "cif" not in stored_meta["versions"]:
+            stored_meta["versions"]["cif"] = self.get_program_version("cif")
 
         if "uuid" not in stored_meta:
             stored_meta["uuid"] = str(uuid.uuid4())
 
-        if "python_version" not in stored_meta:
-            stored_meta["python_version"] = platform.python_version()
-
         if "platform" not in stored_meta:
             stored_meta["platform"] = platform.platform()
 
@@ -382,6 +397,17 @@ class Extension(metaclass=abc.ABCMeta):
         finally:
             return version
 
+    def get_program_version(self, program, version_arg="--version"):
+        version = "unknown"
+        try:
+            version = subprocess.check_output(
+                [program, version_arg], stderr=subprocess.DEVNULL, universal_newlines=True
+            ).strip()
+        finally:
+            if version.startswith("gcc"):
+                version = re.sub(r'\nCopyright[\s\S]*', '', version)
+            return version
+
     def __get_cmd_chunk(self, cmds, chunk_size=1000):
         cmds_it = iter(cmds)
 
@@ -503,17 +529,15 @@ class Extension(metaclass=abc.ABCMeta):
         clade_modules = [x for x in sys.modules if x.startswith("clade")]
 
         """Import all Python modules located in 'extensions' folder."""
-        for root, _, filenames in os.walk(os.path.dirname(__file__)):
+        for _, _, filenames in os.walk(os.path.dirname(__file__)):
             for filename in fnmatch.filter(filenames, "*.py"):
-                module_name = os.path.splitext(os.path.basename(filename))[0]
+                module_name = "." + os.path.splitext(os.path.basename(filename))[0]
 
                 for module in clade_modules:
                     if module.endswith(module_name):
                         break
                 else:
-                    sys.path.insert(0, root)
-                    __import__(module_name)
-                    sys.path.pop(0)
+                    importlib.import_module(module_name, "clade.extensions")
 
     @staticmethod
     def find_subclass(ext_name):
